analphipy.Phi\_sw
=================

.. currentmodule:: analphipy

.. autoclass:: Phi_sw

   
   ..
      .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:
   
      ~Phi_sw.__init__
      ~Phi_sw.asdict
      ~Phi_sw.assign
      ~Phi_sw.assign_min_numeric
      ~Phi_sw.cut
      ~Phi_sw.dphidr
      ~Phi_sw.lfs
      ~Phi_sw.minimize
      ~Phi_sw.new_like
      ~Phi_sw.phi
      ~Phi_sw.to_measures
      ~Phi_sw.to_nf
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree:
   
      ~Phi_sw.sig
      ~Phi_sw.eps
      ~Phi_sw.lam
      ~Phi_sw.phi_min
      ~Phi_sw.r_min
      ~Phi_sw.segments
   
   

   
   
   .. rubric:: Dunder Methods

   .. autosummary::
      :toctree:
   
      ~Phi_sw.__repr__
   
   